summaryrefslogtreecommitdiffstats
path: root/knode/headerview.h
diff options
context:
space:
mode:
Diffstat (limited to 'knode/headerview.h')
-rw-r--r--knode/headerview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/knode/headerview.h b/knode/headerview.h
index 78e6f2a6..4a297c81 100644
--- a/knode/headerview.h
+++ b/knode/headerview.h
@@ -21,10 +21,10 @@
#include <kfoldertree.h>
#include <kmime_util.h>
-class KPopupMenu;
+class TDEPopupMenu;
class KNHdrViewItem;
-class KNHeaderView : public KListView {
+class KNHeaderView : public TDEListView {
Q_OBJECT
@@ -73,7 +73,7 @@ class KNHeaderView : public KListView {
protected:
void activeRemoved() { mActiveItem = 0; }
/**
* Reimplemented to avoid that KListview reloads the alternate
* background on palette changes.
*/
virtual bool event( TQEvent *e );
@@ -93,7 +93,7 @@ class KNHeaderView : public KListView {
KNHdrViewItem *mActiveItem;
KPaintInfo mPaintInfo;
KMime::DateFormatter mDateFormatter;
- KPopupMenu *mPopup;
+ TDEPopupMenu *mPopup;
bool mShowingFolder;
bool mInitDone;
@@ -73,7 +73,7 @@ class KNHeaderView : public KListView {
void activeRemoved() { mActiveItem = 0; }
/**
- * Reimplemented to avoid that KListview reloads the alternate
+ * Reimplemented to avoid that TDEListview reloads the alternate
* background on palette changes.
*/